package de.intevation.mxd.reader;

import java.io.IOException;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IMarkerSymbol;
import com.esri.arcgis.display.MarkerLineSymbol;
import com.esri.arcgis.display.esriSimpleLineStyle;
import com.esri.arcgis.display.MultiLayerMarkerSymbol;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;
import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads marker line symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class MarkerLineSymbolReader implements ISymbolReader{

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(MarkerLineSymbolReader.class);

    /**
     * Private member.
     */
    private Element renderer;
    private MarkerLineSymbol symbol;
    private MapToXMLUtils util;


    public MarkerLineSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof MarkerLineSymbol) {
            this.symbol = (MarkerLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a MarkerLineSymbol!");
        }
    }

    /**
     * Setter for the parent XML element.
     *
     * @param parent The XML parent node.
     */
    public void setParent(Element parent) {
        this.renderer = parent;
    }

    /**
     * Setter for XML document helper.
     *
     * @param util The helper class for storing map information.
     */
    public void setUtil(MapToXMLUtils util) {
        this.util = util;
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws IOException {
        logger.debug("read()");
        try {
            IMarkerSymbol sym = symbol.getMarkerSymbol();
            if(sym instanceof MultiLayerMarkerSymbol) {
                ISymbolReader sreader = new MultiLayerMarkerSymbolReader(sym);
                sreader.setParent(renderer);
                sreader.setUtil(util);
                sreader.read();
            }
            else {
                logger.debug("The type of " + sym.getClass().toString() +
                             " is not implemented!");
                System.out.println(
                        "No known instance: " + sym.getClass().toString());
            }
        }
        catch (Exception e) {
            e.printStackTrace();
        }
        return renderer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
